/****************************************************************************
** Meta object code from reading C++ file 'dblockdevice.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "dblockdevice.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dblockdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBlockDevice_t {
    QByteArrayData data[134];
    char stringdata0[1722];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBlockDevice_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBlockDevice_t qt_meta_stringdata_DBlockDevice = {
    {
QT_MOC_LITERAL(0, 0, 12), // "DBlockDevice"
QT_MOC_LITERAL(1, 13, 20), // "hasFileSystemChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 13), // "hasFileSystem"
QT_MOC_LITERAL(4, 49, 19), // "hasPartitionChanged"
QT_MOC_LITERAL(5, 69, 12), // "hasPartition"
QT_MOC_LITERAL(6, 82, 18), // "isEncryptedChanged"
QT_MOC_LITERAL(7, 101, 11), // "isEncrypted"
QT_MOC_LITERAL(8, 113, 20), // "configurationChanged"
QT_MOC_LITERAL(9, 134, 34), // "QList<QPair<QString,QVariantM..."
QT_MOC_LITERAL(10, 169, 13), // "configuration"
QT_MOC_LITERAL(11, 183, 26), // "cryptoBackingDeviceChanged"
QT_MOC_LITERAL(12, 210, 19), // "cryptoBackingDevice"
QT_MOC_LITERAL(13, 230, 15), // "hintAutoChanged"
QT_MOC_LITERAL(14, 246, 8), // "hintAuto"
QT_MOC_LITERAL(15, 255, 19), // "hintIconNameChanged"
QT_MOC_LITERAL(16, 275, 12), // "hintIconName"
QT_MOC_LITERAL(17, 288, 17), // "hintIgnoreChanged"
QT_MOC_LITERAL(18, 306, 10), // "hintIgnore"
QT_MOC_LITERAL(19, 317, 15), // "hintNameChanged"
QT_MOC_LITERAL(20, 333, 8), // "hintName"
QT_MOC_LITERAL(21, 342, 24), // "hintPartitionableChanged"
QT_MOC_LITERAL(22, 367, 17), // "hintPartitionable"
QT_MOC_LITERAL(23, 385, 27), // "hintSymbolicIconNameChanged"
QT_MOC_LITERAL(24, 413, 20), // "hintSymbolicIconName"
QT_MOC_LITERAL(25, 434, 14), // "idLabelChanged"
QT_MOC_LITERAL(26, 449, 7), // "idLabel"
QT_MOC_LITERAL(27, 457, 13), // "idTypeChanged"
QT_MOC_LITERAL(28, 471, 6), // "idType"
QT_MOC_LITERAL(29, 478, 13), // "fsTypeChanged"
QT_MOC_LITERAL(30, 492, 13), // "idUUIDChanged"
QT_MOC_LITERAL(31, 506, 6), // "idUUID"
QT_MOC_LITERAL(32, 513, 14), // "idUsageChanged"
QT_MOC_LITERAL(33, 528, 7), // "idUsage"
QT_MOC_LITERAL(34, 536, 16), // "idVersionChanged"
QT_MOC_LITERAL(35, 553, 9), // "idVersion"
QT_MOC_LITERAL(36, 563, 13), // "mDRaidChanged"
QT_MOC_LITERAL(37, 577, 6), // "mDRaid"
QT_MOC_LITERAL(38, 584, 19), // "mDRaidMemberChanged"
QT_MOC_LITERAL(39, 604, 12), // "mDRaidMember"
QT_MOC_LITERAL(40, 617, 22), // "preferredDeviceChanged"
QT_MOC_LITERAL(41, 640, 15), // "preferredDevice"
QT_MOC_LITERAL(42, 656, 15), // "readOnlyChanged"
QT_MOC_LITERAL(43, 672, 8), // "readOnly"
QT_MOC_LITERAL(44, 681, 11), // "sizeChanged"
QT_MOC_LITERAL(45, 693, 4), // "size"
QT_MOC_LITERAL(46, 698, 15), // "symlinksChanged"
QT_MOC_LITERAL(47, 714, 8), // "symlinks"
QT_MOC_LITERAL(48, 723, 28), // "userspaceMountOptionsChanged"
QT_MOC_LITERAL(49, 752, 21), // "userspaceMountOptions"
QT_MOC_LITERAL(50, 774, 13), // "ptTypeChanged"
QT_MOC_LITERAL(51, 788, 18), // "mountPointsChanged"
QT_MOC_LITERAL(52, 807, 11), // "mountPoints"
QT_MOC_LITERAL(53, 819, 25), // "childConfigurationChanged"
QT_MOC_LITERAL(54, 845, 18), // "childConfiguration"
QT_MOC_LITERAL(55, 864, 22), // "cleartextDeviceChanged"
QT_MOC_LITERAL(56, 887, 15), // "cleartextDevice"
QT_MOC_LITERAL(57, 903, 15), // "setWatchChanges"
QT_MOC_LITERAL(58, 919, 12), // "watchChanges"
QT_MOC_LITERAL(59, 932, 20), // "addConfigurationItem"
QT_MOC_LITERAL(60, 953, 26), // "QPair<QString,QVariantMap>"
QT_MOC_LITERAL(61, 980, 4), // "item"
QT_MOC_LITERAL(62, 985, 7), // "options"
QT_MOC_LITERAL(63, 993, 6), // "format"
QT_MOC_LITERAL(64, 1000, 4), // "type"
QT_MOC_LITERAL(65, 1005, 6), // "FSType"
QT_MOC_LITERAL(66, 1012, 22), // "getSecretConfiguration"
QT_MOC_LITERAL(67, 1035, 10), // "openDevice"
QT_MOC_LITERAL(68, 1046, 23), // "QDBusUnixFileDescriptor"
QT_MOC_LITERAL(69, 1070, 4), // "mode"
QT_MOC_LITERAL(70, 1075, 13), // "openForBackup"
QT_MOC_LITERAL(71, 1089, 16), // "openForBenchmark"
QT_MOC_LITERAL(72, 1106, 14), // "openForRestore"
QT_MOC_LITERAL(73, 1121, 23), // "removeConfigurationItem"
QT_MOC_LITERAL(74, 1145, 6), // "rescan"
QT_MOC_LITERAL(75, 1152, 23), // "updateConfigurationItem"
QT_MOC_LITERAL(76, 1176, 8), // "old_item"
QT_MOC_LITERAL(77, 1185, 8), // "new_item"
QT_MOC_LITERAL(78, 1194, 5), // "mount"
QT_MOC_LITERAL(79, 1200, 7), // "unmount"
QT_MOC_LITERAL(80, 1208, 11), // "canSetLabel"
QT_MOC_LITERAL(81, 1220, 8), // "setLabel"
QT_MOC_LITERAL(82, 1229, 5), // "label"
QT_MOC_LITERAL(83, 1235, 16), // "changePassphrase"
QT_MOC_LITERAL(84, 1252, 10), // "passphrase"
QT_MOC_LITERAL(85, 1263, 14), // "new_passphrase"
QT_MOC_LITERAL(86, 1278, 4), // "lock"
QT_MOC_LITERAL(87, 1283, 6), // "unlock"
QT_MOC_LITERAL(88, 1290, 17), // "onInterfacesAdded"
QT_MOC_LITERAL(89, 1308, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(90, 1324, 11), // "object_path"
QT_MOC_LITERAL(91, 1336, 25), // "QMap<QString,QVariantMap>"
QT_MOC_LITERAL(92, 1362, 25), // "interfaces_and_properties"
QT_MOC_LITERAL(93, 1388, 19), // "onInterfacesRemoved"
QT_MOC_LITERAL(94, 1408, 10), // "interfaces"
QT_MOC_LITERAL(95, 1419, 19), // "onPropertiesChanged"
QT_MOC_LITERAL(96, 1439, 9), // "interface"
QT_MOC_LITERAL(97, 1449, 18), // "changed_properties"
QT_MOC_LITERAL(98, 1468, 4), // "path"
QT_MOC_LITERAL(99, 1473, 12), // "isLoopDevice"
QT_MOC_LITERAL(100, 1486, 6), // "device"
QT_MOC_LITERAL(101, 1493, 12), // "deviceNumber"
QT_MOC_LITERAL(102, 1506, 5), // "drive"
QT_MOC_LITERAL(103, 1512, 10), // "hintSystem"
QT_MOC_LITERAL(104, 1523, 2), // "id"
QT_MOC_LITERAL(105, 1526, 6), // "fsType"
QT_MOC_LITERAL(106, 1533, 6), // "ptType"
QT_MOC_LITERAL(107, 1540, 6), // "PTType"
QT_MOC_LITERAL(108, 1547, 9), // "InvalidPT"
QT_MOC_LITERAL(109, 1557, 3), // "MBR"
QT_MOC_LITERAL(110, 1561, 3), // "GPT"
QT_MOC_LITERAL(111, 1565, 8), // "UnknowPT"
QT_MOC_LITERAL(112, 1574, 9), // "InvalidFS"
QT_MOC_LITERAL(113, 1584, 8), // "UnknowFS"
QT_MOC_LITERAL(114, 1593, 4), // "ext2"
QT_MOC_LITERAL(115, 1598, 4), // "ext3"
QT_MOC_LITERAL(116, 1603, 4), // "ext4"
QT_MOC_LITERAL(117, 1608, 5), // "fat12"
QT_MOC_LITERAL(118, 1614, 5), // "fat16"
QT_MOC_LITERAL(119, 1620, 5), // "fat32"
QT_MOC_LITERAL(120, 1626, 5), // "btrfs"
QT_MOC_LITERAL(121, 1632, 4), // "f2fs"
QT_MOC_LITERAL(122, 1637, 8), // "hfs_plus"
QT_MOC_LITERAL(123, 1646, 5), // "minix"
QT_MOC_LITERAL(124, 1652, 6), // "nilfs2"
QT_MOC_LITERAL(125, 1659, 4), // "ntfs"
QT_MOC_LITERAL(126, 1664, 7), // "reiser4"
QT_MOC_LITERAL(127, 1672, 4), // "vfat"
QT_MOC_LITERAL(128, 1677, 7), // "iso9660"
QT_MOC_LITERAL(129, 1685, 3), // "jfs"
QT_MOC_LITERAL(130, 1689, 3), // "xfs"
QT_MOC_LITERAL(131, 1693, 4), // "swap"
QT_MOC_LITERAL(132, 1698, 11), // "LVM2_member"
QT_MOC_LITERAL(133, 1710, 11) // "crypto_LUKS"

    },
    "DBlockDevice\0hasFileSystemChanged\0\0"
    "hasFileSystem\0hasPartitionChanged\0"
    "hasPartition\0isEncryptedChanged\0"
    "isEncrypted\0configurationChanged\0"
    "QList<QPair<QString,QVariantMap> >\0"
    "configuration\0cryptoBackingDeviceChanged\0"
    "cryptoBackingDevice\0hintAutoChanged\0"
    "hintAuto\0hintIconNameChanged\0hintIconName\0"
    "hintIgnoreChanged\0hintIgnore\0"
    "hintNameChanged\0hintName\0"
    "hintPartitionableChanged\0hintPartitionable\0"
    "hintSymbolicIconNameChanged\0"
    "hintSymbolicIconName\0idLabelChanged\0"
    "idLabel\0idTypeChanged\0idType\0fsTypeChanged\0"
    "idUUIDChanged\0idUUID\0idUsageChanged\0"
    "idUsage\0idVersionChanged\0idVersion\0"
    "mDRaidChanged\0mDRaid\0mDRaidMemberChanged\0"
    "mDRaidMember\0preferredDeviceChanged\0"
    "preferredDevice\0readOnlyChanged\0"
    "readOnly\0sizeChanged\0size\0symlinksChanged\0"
    "symlinks\0userspaceMountOptionsChanged\0"
    "userspaceMountOptions\0ptTypeChanged\0"
    "mountPointsChanged\0mountPoints\0"
    "childConfigurationChanged\0childConfiguration\0"
    "cleartextDeviceChanged\0cleartextDevice\0"
    "setWatchChanges\0watchChanges\0"
    "addConfigurationItem\0QPair<QString,QVariantMap>\0"
    "item\0options\0format\0type\0FSType\0"
    "getSecretConfiguration\0openDevice\0"
    "QDBusUnixFileDescriptor\0mode\0openForBackup\0"
    "openForBenchmark\0openForRestore\0"
    "removeConfigurationItem\0rescan\0"
    "updateConfigurationItem\0old_item\0"
    "new_item\0mount\0unmount\0canSetLabel\0"
    "setLabel\0label\0changePassphrase\0"
    "passphrase\0new_passphrase\0lock\0unlock\0"
    "onInterfacesAdded\0QDBusObjectPath\0"
    "object_path\0QMap<QString,QVariantMap>\0"
    "interfaces_and_properties\0onInterfacesRemoved\0"
    "interfaces\0onPropertiesChanged\0interface\0"
    "changed_properties\0path\0isLoopDevice\0"
    "device\0deviceNumber\0drive\0hintSystem\0"
    "id\0fsType\0ptType\0PTType\0InvalidPT\0MBR\0"
    "GPT\0UnknowPT\0InvalidFS\0UnknowFS\0ext2\0"
    "ext3\0ext4\0fat12\0fat16\0fat32\0btrfs\0"
    "f2fs\0hfs_plus\0minix\0nilfs2\0ntfs\0reiser4\0"
    "vfat\0iso9660\0jfs\0xfs\0swap\0LVM2_member\0"
    "crypto_LUKS"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBlockDevice[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      51,   14, // methods
      36,  442, // properties
       2,  586, // enums/sets
       0,    0, // constructors
       0,       // flags
      28,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  269,    2, 0x06 /* Public */,
       4,    1,  272,    2, 0x06 /* Public */,
       6,    1,  275,    2, 0x06 /* Public */,
       8,    1,  278,    2, 0x06 /* Public */,
      11,    1,  281,    2, 0x06 /* Public */,
      13,    1,  284,    2, 0x06 /* Public */,
      15,    1,  287,    2, 0x06 /* Public */,
      17,    1,  290,    2, 0x06 /* Public */,
      19,    1,  293,    2, 0x06 /* Public */,
      21,    1,  296,    2, 0x06 /* Public */,
      23,    1,  299,    2, 0x06 /* Public */,
      25,    1,  302,    2, 0x06 /* Public */,
      27,    1,  305,    2, 0x06 /* Public */,
      29,    0,  308,    2, 0x06 /* Public */,
      30,    1,  309,    2, 0x06 /* Public */,
      32,    1,  312,    2, 0x06 /* Public */,
      34,    1,  315,    2, 0x06 /* Public */,
      36,    1,  318,    2, 0x06 /* Public */,
      38,    1,  321,    2, 0x06 /* Public */,
      40,    1,  324,    2, 0x06 /* Public */,
      42,    1,  327,    2, 0x06 /* Public */,
      44,    1,  330,    2, 0x06 /* Public */,
      46,    1,  333,    2, 0x06 /* Public */,
      48,    1,  336,    2, 0x06 /* Public */,
      50,    0,  339,    2, 0x06 /* Public */,
      51,    1,  340,    2, 0x06 /* Public */,
      53,    1,  343,    2, 0x06 /* Public */,
      55,    1,  346,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      57,    1,  349,    2, 0x0a /* Public */,
      59,    2,  352,    2, 0x0a /* Public */,
      63,    2,  357,    2, 0x0a /* Public */,
      63,    2,  362,    2, 0x0a /* Public */,
      66,    1,  367,    2, 0x0a /* Public */,
      67,    2,  370,    2, 0x0a /* Public */,
      70,    1,  375,    2, 0x0a /* Public */,
      71,    1,  378,    2, 0x0a /* Public */,
      72,    1,  381,    2, 0x0a /* Public */,
      73,    2,  384,    2, 0x0a /* Public */,
      74,    1,  389,    2, 0x0a /* Public */,
      75,    3,  392,    2, 0x0a /* Public */,
      78,    1,  399,    2, 0x0a /* Public */,
      79,    1,  402,    2, 0x0a /* Public */,
      80,    0,  405,    2, 0x0a /* Public */,
      81,    2,  406,    2, 0x0a /* Public */,
      83,    3,  411,    2, 0x0a /* Public */,
      86,    1,  418,    2, 0x0a /* Public */,
      87,    2,  421,    2, 0x0a /* Public */,
      56,    0,  426,    2, 0x0a /* Public */,
      88,    2,  427,    2, 0x08 /* Private */,
      93,    2,  432,    2, 0x08 /* Private */,
      95,    2,  437,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   31,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::QString,   37,
    QMetaType::Void, QMetaType::QString,   39,
    QMetaType::Void, QMetaType::QByteArray,   41,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void, QMetaType::ULongLong,   45,
    QMetaType::Void, QMetaType::QByteArrayList,   47,
    QMetaType::Void, QMetaType::QStringList,   49,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArrayList,   52,
    QMetaType::Void, 0x80000000 | 9,   54,
    QMetaType::Void, QMetaType::QString,   56,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   58,
    QMetaType::Void, 0x80000000 | 60, QMetaType::QVariantMap,   61,   62,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   64,   62,
    QMetaType::Void, 0x80000000 | 65, QMetaType::QVariantMap,   64,   62,
    0x80000000 | 9, QMetaType::QVariantMap,   62,
    0x80000000 | 68, QMetaType::QString, QMetaType::QVariantMap,   69,   62,
    0x80000000 | 68, QMetaType::QVariantMap,   62,
    0x80000000 | 68, QMetaType::QVariantMap,   62,
    0x80000000 | 68, QMetaType::QVariantMap,   62,
    QMetaType::Void, 0x80000000 | 60, QMetaType::QVariantMap,   61,   62,
    QMetaType::Void, QMetaType::QVariantMap,   62,
    QMetaType::Void, 0x80000000 | 60, 0x80000000 | 60, QMetaType::QVariantMap,   76,   77,   62,
    QMetaType::QString, QMetaType::QVariantMap,   62,
    QMetaType::Void, QMetaType::QVariantMap,   62,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   82,   62,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QVariantMap,   84,   85,   62,
    QMetaType::Void, QMetaType::QVariantMap,   62,
    QMetaType::QString, QMetaType::QString, QMetaType::QVariantMap,   84,   62,
    QMetaType::QString,
    QMetaType::Void, 0x80000000 | 89, 0x80000000 | 91,   90,   92,
    QMetaType::Void, 0x80000000 | 89, QMetaType::QStringList,   90,   94,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   96,   97,

 // properties: name, type, flags
      98, QMetaType::QString, 0x00095c01,
      58, QMetaType::Bool, 0x00095103,
       3, QMetaType::Bool, 0x00495001,
       5, QMetaType::Bool, 0x00495001,
       7, QMetaType::Bool, 0x00495001,
      99, QMetaType::Bool, 0x00095001,
      10, 0x80000000 | 9, 0x00495009,
      12, QMetaType::QString, 0x00495001,
     100, QMetaType::QByteArray, 0x00095001,
     101, QMetaType::ULongLong, 0x00095001,
     102, QMetaType::QString, 0x00095001,
      14, QMetaType::Bool, 0x00495001,
      16, QMetaType::QString, 0x00495001,
      18, QMetaType::Bool, 0x00495001,
      20, QMetaType::QString, 0x00495001,
      22, QMetaType::Bool, 0x00495001,
      24, QMetaType::QString, 0x00495001,
     103, QMetaType::Bool, 0x00095001,
     104, QMetaType::QString, 0x00095001,
      26, QMetaType::QString, 0x00495001,
      28, QMetaType::QString, 0x00495001,
     105, 0x80000000 | 65, 0x00495009,
      31, QMetaType::QString, 0x00495001,
      33, QMetaType::QString, 0x00495001,
      35, QMetaType::QString, 0x00495001,
      37, QMetaType::QString, 0x00495001,
      39, QMetaType::QString, 0x00495001,
      41, QMetaType::QByteArray, 0x00495001,
      43, QMetaType::Bool, 0x00495001,
      45, QMetaType::ULongLong, 0x00495001,
      47, QMetaType::QByteArrayList, 0x00495001,
      49, QMetaType::QStringList, 0x00495001,
      52, QMetaType::QByteArrayList, 0x00495001,
     106, 0x80000000 | 107, 0x00495009,
      54, 0x80000000 | 9, 0x00495009,
      56, QMetaType::QString, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       0,
       1,
       2,
       0,
       3,
       4,
       0,
       0,
       0,
       5,
       6,
       7,
       8,
       9,
      10,
       0,
       0,
      11,
      12,
      13,
      14,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      25,
      24,
      26,
      27,

 // enums: name, alias, flags, count, data
     107,  107, 0x0,    4,  596,
      65,   65, 0x0,   22,  604,

 // enum data: key, value
     108, uint(DBlockDevice::InvalidPT),
     109, uint(DBlockDevice::MBR),
     110, uint(DBlockDevice::GPT),
     111, uint(DBlockDevice::UnknowPT),
     112, uint(DBlockDevice::InvalidFS),
     113, uint(DBlockDevice::UnknowFS),
     114, uint(DBlockDevice::ext2),
     115, uint(DBlockDevice::ext3),
     116, uint(DBlockDevice::ext4),
     117, uint(DBlockDevice::fat12),
     118, uint(DBlockDevice::fat16),
     119, uint(DBlockDevice::fat32),
     120, uint(DBlockDevice::btrfs),
     121, uint(DBlockDevice::f2fs),
     122, uint(DBlockDevice::hfs_plus),
     123, uint(DBlockDevice::minix),
     124, uint(DBlockDevice::nilfs2),
     125, uint(DBlockDevice::ntfs),
     126, uint(DBlockDevice::reiser4),
     127, uint(DBlockDevice::vfat),
     128, uint(DBlockDevice::iso9660),
     129, uint(DBlockDevice::jfs),
     130, uint(DBlockDevice::xfs),
     131, uint(DBlockDevice::swap),
     132, uint(DBlockDevice::LVM2_member),
     133, uint(DBlockDevice::crypto_LUKS),

       0        // eod
};

void DBlockDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DBlockDevice *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hasFileSystemChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->hasPartitionChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->isEncryptedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->configurationChanged((*reinterpret_cast< QList<QPair<QString,QVariantMap> >(*)>(_a[1]))); break;
        case 4: _t->cryptoBackingDeviceChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->hintAutoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->hintIconNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 7: _t->hintIgnoreChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->hintNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 9: _t->hintPartitionableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->hintSymbolicIconNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->idLabelChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 12: _t->idTypeChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 13: _t->fsTypeChanged(); break;
        case 14: _t->idUUIDChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 15: _t->idUsageChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 16: _t->idVersionChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 17: _t->mDRaidChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 18: _t->mDRaidMemberChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 19: _t->preferredDeviceChanged((*reinterpret_cast< QByteArray(*)>(_a[1]))); break;
        case 20: _t->readOnlyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->sizeChanged((*reinterpret_cast< qulonglong(*)>(_a[1]))); break;
        case 22: _t->symlinksChanged((*reinterpret_cast< QByteArrayList(*)>(_a[1]))); break;
        case 23: _t->userspaceMountOptionsChanged((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 24: _t->ptTypeChanged(); break;
        case 25: _t->mountPointsChanged((*reinterpret_cast< const QByteArrayList(*)>(_a[1]))); break;
        case 26: _t->childConfigurationChanged((*reinterpret_cast< QList<QPair<QString,QVariantMap> >(*)>(_a[1]))); break;
        case 27: _t->cleartextDeviceChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->setWatchChanges((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->addConfigurationItem((*reinterpret_cast< const QPair<QString,QVariantMap>(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 30: _t->format((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 31: _t->format((*reinterpret_cast< const FSType(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 32: { QList<QPair<QString,QVariantMap> > _r = _t->getSecretConfiguration((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QList<QPair<QString,QVariantMap> >*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusUnixFileDescriptor _r = _t->openDevice((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusUnixFileDescriptor _r = _t->openForBackup((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusUnixFileDescriptor _r = _t->openForBenchmark((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusUnixFileDescriptor _r = _t->openForRestore((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->removeConfigurationItem((*reinterpret_cast< const QPair<QString,QVariantMap>(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 38: _t->rescan((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 39: _t->updateConfigurationItem((*reinterpret_cast< const QPair<QString,QVariantMap>(*)>(_a[1])),(*reinterpret_cast< const QPair<QString,QVariantMap>(*)>(_a[2])),(*reinterpret_cast< const QVariantMap(*)>(_a[3]))); break;
        case 40: { QString _r = _t->mount((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->unmount((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 42: { bool _r = _t->canSetLabel();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->setLabel((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 44: _t->changePassphrase((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariantMap(*)>(_a[3]))); break;
        case 45: _t->lock((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 46: { QString _r = _t->unlock((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QString _r = _t->cleartextDevice();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->onInterfacesAdded((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< const QMap<QString,QVariantMap>(*)>(_a[2]))); break;
        case 49: _t->onInterfacesRemoved((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 50: _t->onPropertiesChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hasFileSystemChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hasPartitionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::isEncryptedChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QList<QPair<QString,QVariantMap>> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::configurationChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::cryptoBackingDeviceChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintAutoChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintIconNameChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintIgnoreChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintNameChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintPartitionableChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::hintSymbolicIconNameChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::idLabelChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::idTypeChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::fsTypeChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::idUUIDChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::idUsageChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::idVersionChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::mDRaidChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::mDRaidMemberChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::preferredDeviceChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::readOnlyChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(qulonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::sizeChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QByteArrayList );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::symlinksChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QStringList );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::userspaceMountOptionsChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::ptTypeChanged)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(const QByteArrayList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::mountPointsChanged)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(QList<QPair<QString,QVariantMap>> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::childConfigurationChanged)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (DBlockDevice::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockDevice::cleartextDeviceChanged)) {
                *result = 27;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DBlockDevice *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->watchChanges(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->hasFileSystem(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->hasPartition(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isEncrypted(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isLoopDevice(); break;
        case 6: *reinterpret_cast< QList<QPair<QString,QVariantMap> >*>(_v) = _t->configuration(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->cryptoBackingDevice(); break;
        case 8: *reinterpret_cast< QByteArray*>(_v) = _t->device(); break;
        case 9: *reinterpret_cast< qulonglong*>(_v) = _t->deviceNumber(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->drive(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->hintAuto(); break;
        case 12: *reinterpret_cast< QString*>(_v) = _t->hintIconName(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->hintIgnore(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->hintName(); break;
        case 15: *reinterpret_cast< bool*>(_v) = _t->hintPartitionable(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->hintSymbolicIconName(); break;
        case 17: *reinterpret_cast< bool*>(_v) = _t->hintSystem(); break;
        case 18: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 19: *reinterpret_cast< QString*>(_v) = _t->idLabel(); break;
        case 20: *reinterpret_cast< QString*>(_v) = _t->idType(); break;
        case 21: *reinterpret_cast< FSType*>(_v) = _t->fsType(); break;
        case 22: *reinterpret_cast< QString*>(_v) = _t->idUUID(); break;
        case 23: *reinterpret_cast< QString*>(_v) = _t->idUsage(); break;
        case 24: *reinterpret_cast< QString*>(_v) = _t->idVersion(); break;
        case 25: *reinterpret_cast< QString*>(_v) = _t->mDRaid(); break;
        case 26: *reinterpret_cast< QString*>(_v) = _t->mDRaidMember(); break;
        case 27: *reinterpret_cast< QByteArray*>(_v) = _t->preferredDevice(); break;
        case 28: *reinterpret_cast< bool*>(_v) = _t->readOnly(); break;
        case 29: *reinterpret_cast< qulonglong*>(_v) = _t->size(); break;
        case 30: *reinterpret_cast< QByteArrayList*>(_v) = _t->symlinks(); break;
        case 31: *reinterpret_cast< QStringList*>(_v) = _t->userspaceMountOptions(); break;
        case 32: *reinterpret_cast< QByteArrayList*>(_v) = _t->mountPoints(); break;
        case 33: *reinterpret_cast< PTType*>(_v) = _t->ptType(); break;
        case 34: *reinterpret_cast< QList<QPair<QString,QVariantMap> >*>(_v) = _t->childConfiguration(); break;
        case 35: *reinterpret_cast< QString*>(_v) = _t->cleartextDevice(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DBlockDevice *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setWatchChanges(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DBlockDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DBlockDevice.data,
    qt_meta_data_DBlockDevice,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DBlockDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBlockDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBlockDevice.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBlockDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 51;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 36;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 36;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 36;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 36;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 36;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DBlockDevice::hasFileSystemChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DBlockDevice::hasPartitionChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DBlockDevice::isEncryptedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DBlockDevice::configurationChanged(QList<QPair<QString,QVariantMap>> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DBlockDevice::cryptoBackingDeviceChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DBlockDevice::hintAutoChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DBlockDevice::hintIconNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DBlockDevice::hintIgnoreChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DBlockDevice::hintNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void DBlockDevice::hintPartitionableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DBlockDevice::hintSymbolicIconNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void DBlockDevice::idLabelChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void DBlockDevice::idTypeChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void DBlockDevice::fsTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DBlockDevice::idUUIDChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void DBlockDevice::idUsageChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void DBlockDevice::idVersionChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void DBlockDevice::mDRaidChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void DBlockDevice::mDRaidMemberChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void DBlockDevice::preferredDeviceChanged(QByteArray _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void DBlockDevice::readOnlyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void DBlockDevice::sizeChanged(qulonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void DBlockDevice::symlinksChanged(QByteArrayList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void DBlockDevice::userspaceMountOptionsChanged(QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void DBlockDevice::ptTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DBlockDevice::mountPointsChanged(const QByteArrayList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void DBlockDevice::childConfigurationChanged(QList<QPair<QString,QVariantMap>> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void DBlockDevice::cleartextDeviceChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 27, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
