/****************************************************************************
** Meta object code from reading C++ file 'ddiskdevice.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "ddiskdevice.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddiskdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DDiskDevice_t {
    QByteArrayData data[37];
    char stringdata0[407];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DDiskDevice_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DDiskDevice_t qt_meta_stringdata_DDiskDevice = {
    {
QT_MOC_LITERAL(0, 0, 11), // "DDiskDevice"
QT_MOC_LITERAL(1, 12, 5), // "eject"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 7), // "options"
QT_MOC_LITERAL(4, 27, 8), // "powerOff"
QT_MOC_LITERAL(5, 36, 16), // "setConfiguration"
QT_MOC_LITERAL(6, 53, 5), // "value"
QT_MOC_LITERAL(7, 59, 4), // "path"
QT_MOC_LITERAL(8, 64, 11), // "canPowerOff"
QT_MOC_LITERAL(9, 76, 13), // "configuration"
QT_MOC_LITERAL(10, 90, 13), // "connectionBus"
QT_MOC_LITERAL(11, 104, 9), // "ejectable"
QT_MOC_LITERAL(12, 114, 2), // "id"
QT_MOC_LITERAL(13, 117, 5), // "media"
QT_MOC_LITERAL(14, 123, 14), // "mediaAvailable"
QT_MOC_LITERAL(15, 138, 19), // "mediaChangeDetected"
QT_MOC_LITERAL(16, 158, 18), // "mediaCompatibility"
QT_MOC_LITERAL(17, 177, 14), // "mediaRemovable"
QT_MOC_LITERAL(18, 192, 5), // "model"
QT_MOC_LITERAL(19, 198, 7), // "optical"
QT_MOC_LITERAL(20, 206, 12), // "opticalBlank"
QT_MOC_LITERAL(21, 219, 21), // "opticalNumAudioTracks"
QT_MOC_LITERAL(22, 241, 20), // "opticalNumDataTracks"
QT_MOC_LITERAL(23, 262, 18), // "opticalNumSessions"
QT_MOC_LITERAL(24, 281, 16), // "opticalNumTracks"
QT_MOC_LITERAL(25, 298, 9), // "removable"
QT_MOC_LITERAL(26, 308, 8), // "revision"
QT_MOC_LITERAL(27, 317, 12), // "rotationRate"
QT_MOC_LITERAL(28, 330, 4), // "seat"
QT_MOC_LITERAL(29, 335, 6), // "serial"
QT_MOC_LITERAL(30, 342, 9), // "siblingId"
QT_MOC_LITERAL(31, 352, 4), // "size"
QT_MOC_LITERAL(32, 357, 7), // "sortKey"
QT_MOC_LITERAL(33, 365, 12), // "timeDetected"
QT_MOC_LITERAL(34, 378, 17), // "timeMediaDetected"
QT_MOC_LITERAL(35, 396, 6), // "vendor"
QT_MOC_LITERAL(36, 403, 3) // "WWN"

    },
    "DDiskDevice\0eject\0\0options\0powerOff\0"
    "setConfiguration\0value\0path\0canPowerOff\0"
    "configuration\0connectionBus\0ejectable\0"
    "id\0media\0mediaAvailable\0mediaChangeDetected\0"
    "mediaCompatibility\0mediaRemovable\0"
    "model\0optical\0opticalBlank\0"
    "opticalNumAudioTracks\0opticalNumDataTracks\0"
    "opticalNumSessions\0opticalNumTracks\0"
    "removable\0revision\0rotationRate\0seat\0"
    "serial\0siblingId\0size\0sortKey\0"
    "timeDetected\0timeMediaDetected\0vendor\0"
    "WWN"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DDiskDevice[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
      30,   40, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x0a /* Public */,
       4,    1,   32,    2, 0x0a /* Public */,
       5,    2,   35,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariantMap,    3,
    QMetaType::Void, QMetaType::QVariantMap,    3,
    QMetaType::Void, QMetaType::QVariantMap, QMetaType::QVariantMap,    6,    3,

 // properties: name, type, flags
       7, QMetaType::QString, 0x00095c01,
       8, QMetaType::Bool, 0x00095c01,
       9, QMetaType::QVariantMap, 0x00095c01,
      10, QMetaType::QString, 0x00095c01,
      11, QMetaType::Bool, 0x00095c01,
      12, QMetaType::QString, 0x00095c01,
      13, QMetaType::QString, 0x00095c01,
      14, QMetaType::Bool, 0x00095c01,
      15, QMetaType::Bool, 0x00095c01,
      16, QMetaType::QStringList, 0x00095c01,
      17, QMetaType::Bool, 0x00095c01,
      18, QMetaType::QString, 0x00095c01,
      19, QMetaType::Bool, 0x00095c01,
      20, QMetaType::Bool, 0x00095c01,
      21, QMetaType::UInt, 0x00095c01,
      22, QMetaType::UInt, 0x00095c01,
      23, QMetaType::UInt, 0x00095c01,
      24, QMetaType::UInt, 0x00095c01,
      25, QMetaType::Bool, 0x00095c01,
      26, QMetaType::QString, 0x00095c01,
      27, QMetaType::Int, 0x00095c01,
      28, QMetaType::QString, 0x00095c01,
      29, QMetaType::QString, 0x00095c01,
      30, QMetaType::QString, 0x00095c01,
      31, QMetaType::ULongLong, 0x00095c01,
      32, QMetaType::QString, 0x00095c01,
      33, QMetaType::ULongLong, 0x00095c01,
      34, QMetaType::ULongLong, 0x00095c01,
      35, QMetaType::QString, 0x00095c01,
      36, QMetaType::QString, 0x00095c01,

       0        // eod
};

void DDiskDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DDiskDevice *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->eject((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 1: _t->powerOff((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 2: _t->setConfiguration((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DDiskDevice *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->canPowerOff(); break;
        case 2: *reinterpret_cast< QVariantMap*>(_v) = _t->configuration(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->connectionBus(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->ejectable(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->media(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->mediaAvailable(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->mediaChangeDetected(); break;
        case 9: *reinterpret_cast< QStringList*>(_v) = _t->mediaCompatibility(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->mediaRemovable(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->model(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->optical(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->opticalBlank(); break;
        case 14: *reinterpret_cast< uint*>(_v) = _t->opticalNumAudioTracks(); break;
        case 15: *reinterpret_cast< uint*>(_v) = _t->opticalNumDataTracks(); break;
        case 16: *reinterpret_cast< uint*>(_v) = _t->opticalNumSessions(); break;
        case 17: *reinterpret_cast< uint*>(_v) = _t->opticalNumTracks(); break;
        case 18: *reinterpret_cast< bool*>(_v) = _t->removable(); break;
        case 19: *reinterpret_cast< QString*>(_v) = _t->revision(); break;
        case 20: *reinterpret_cast< int*>(_v) = _t->rotationRate(); break;
        case 21: *reinterpret_cast< QString*>(_v) = _t->seat(); break;
        case 22: *reinterpret_cast< QString*>(_v) = _t->serial(); break;
        case 23: *reinterpret_cast< QString*>(_v) = _t->siblingId(); break;
        case 24: *reinterpret_cast< qulonglong*>(_v) = _t->size(); break;
        case 25: *reinterpret_cast< QString*>(_v) = _t->sortKey(); break;
        case 26: *reinterpret_cast< qulonglong*>(_v) = _t->timeDetected(); break;
        case 27: *reinterpret_cast< qulonglong*>(_v) = _t->timeMediaDetected(); break;
        case 28: *reinterpret_cast< QString*>(_v) = _t->vendor(); break;
        case 29: *reinterpret_cast< QString*>(_v) = _t->WWN(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DDiskDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DDiskDevice.data,
    qt_meta_data_DDiskDevice,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DDiskDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DDiskDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DDiskDevice.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DDiskDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 30;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 30;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 30;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 30;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 30;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
