/****************************************************************************
** Meta object code from reading C++ file 'ddiskmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "ddiskmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddiskmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DDiskManager_t {
    QByteArrayData data[32];
    char stringdata0[457];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DDiskManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DDiskManager_t qt_meta_stringdata_DDiskManager = {
    {
QT_MOC_LITERAL(0, 0, 12), // "DDiskManager"
QT_MOC_LITERAL(1, 13, 16), // "blockDeviceAdded"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 4), // "path"
QT_MOC_LITERAL(4, 36, 18), // "blockDeviceRemoved"
QT_MOC_LITERAL(5, 55, 15), // "diskDeviceAdded"
QT_MOC_LITERAL(6, 71, 17), // "diskDeviceRemoved"
QT_MOC_LITERAL(7, 89, 15), // "fileSystemAdded"
QT_MOC_LITERAL(8, 105, 15), // "blockDevicePath"
QT_MOC_LITERAL(9, 121, 17), // "fileSystemRemoved"
QT_MOC_LITERAL(10, 139, 10), // "mountAdded"
QT_MOC_LITERAL(11, 150, 10), // "mountPoint"
QT_MOC_LITERAL(12, 161, 12), // "mountRemoved"
QT_MOC_LITERAL(13, 174, 18), // "mountPointsChanged"
QT_MOC_LITERAL(14, 193, 14), // "oldMountPoints"
QT_MOC_LITERAL(15, 208, 14), // "newMountPoints"
QT_MOC_LITERAL(16, 223, 8), // "jobAdded"
QT_MOC_LITERAL(17, 232, 7), // "jobPath"
QT_MOC_LITERAL(18, 240, 14), // "opticalChanged"
QT_MOC_LITERAL(19, 255, 15), // "setWatchChanges"
QT_MOC_LITERAL(20, 271, 12), // "watchChanges"
QT_MOC_LITERAL(21, 284, 17), // "onInterfacesAdded"
QT_MOC_LITERAL(22, 302, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(23, 318, 25), // "QMap<QString,QVariantMap>"
QT_MOC_LITERAL(24, 344, 19), // "onInterfacesRemoved"
QT_MOC_LITERAL(25, 364, 11), // "object_path"
QT_MOC_LITERAL(26, 376, 10), // "interfaces"
QT_MOC_LITERAL(27, 387, 19), // "onPropertiesChanged"
QT_MOC_LITERAL(28, 407, 9), // "interface"
QT_MOC_LITERAL(29, 417, 18), // "changed_properties"
QT_MOC_LITERAL(30, 436, 12), // "QDBusMessage"
QT_MOC_LITERAL(31, 449, 7) // "message"

    },
    "DDiskManager\0blockDeviceAdded\0\0path\0"
    "blockDeviceRemoved\0diskDeviceAdded\0"
    "diskDeviceRemoved\0fileSystemAdded\0"
    "blockDevicePath\0fileSystemRemoved\0"
    "mountAdded\0mountPoint\0mountRemoved\0"
    "mountPointsChanged\0oldMountPoints\0"
    "newMountPoints\0jobAdded\0jobPath\0"
    "opticalChanged\0setWatchChanges\0"
    "watchChanges\0onInterfacesAdded\0"
    "QDBusObjectPath\0QMap<QString,QVariantMap>\0"
    "onInterfacesRemoved\0object_path\0"
    "interfaces\0onPropertiesChanged\0interface\0"
    "changed_properties\0QDBusMessage\0message"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DDiskManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       1,  150, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x06 /* Public */,
       4,    1,   92,    2, 0x06 /* Public */,
       5,    1,   95,    2, 0x06 /* Public */,
       6,    1,   98,    2, 0x06 /* Public */,
       7,    1,  101,    2, 0x06 /* Public */,
       9,    1,  104,    2, 0x06 /* Public */,
      10,    2,  107,    2, 0x06 /* Public */,
      12,    2,  112,    2, 0x06 /* Public */,
      13,    3,  117,    2, 0x06 /* Public */,
      16,    1,  124,    2, 0x06 /* Public */,
      18,    1,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    1,  130,    2, 0x0a /* Public */,
      21,    2,  133,    2, 0x08 /* Private */,
      24,    2,  138,    2, 0x08 /* Private */,
      27,    3,  143,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray,    8,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray,    8,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArrayList,    8,   14,   15,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, 0x80000000 | 22, 0x80000000 | 23,    2,    2,
    QMetaType::Void, 0x80000000 | 22, QMetaType::QStringList,   25,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, 0x80000000 | 30,   28,   29,   31,

 // properties: name, type, flags
      20, QMetaType::Bool, 0x00095103,

       0        // eod
};

void DDiskManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DDiskManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->blockDeviceAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->blockDeviceRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->diskDeviceAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->diskDeviceRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->fileSystemAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->fileSystemRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->mountAdded((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 7: _t->mountRemoved((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 8: _t->mountPointsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArrayList(*)>(_a[2])),(*reinterpret_cast< const QByteArrayList(*)>(_a[3]))); break;
        case 9: _t->jobAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->opticalChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setWatchChanges((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->onInterfacesAdded((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< const QMap<QString,QVariantMap>(*)>(_a[2]))); break;
        case 13: _t->onInterfacesRemoved((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 14: _t->onPropertiesChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QDBusMessage(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::blockDeviceAdded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::blockDeviceRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::diskDeviceAdded)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::diskDeviceRemoved)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::fileSystemAdded)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::fileSystemRemoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & , const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::mountAdded)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & , const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::mountRemoved)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & , const QByteArrayList & , const QByteArrayList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::mountPointsChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::jobAdded)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DDiskManager::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDiskManager::opticalChanged)) {
                *result = 10;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DDiskManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->watchChanges(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DDiskManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWatchChanges(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DDiskManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DDiskManager.data,
    qt_meta_data_DDiskManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DDiskManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DDiskManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DDiskManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DDiskManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DDiskManager::blockDeviceAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DDiskManager::blockDeviceRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DDiskManager::diskDeviceAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DDiskManager::diskDeviceRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DDiskManager::fileSystemAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DDiskManager::fileSystemRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DDiskManager::mountAdded(const QString & _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DDiskManager::mountRemoved(const QString & _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DDiskManager::mountPointsChanged(const QString & _t1, const QByteArrayList & _t2, const QByteArrayList & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void DDiskManager::jobAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DDiskManager::opticalChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
