/****************************************************************************
** Meta object code from reading C++ file 'dudisksjob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "dudisksjob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dudisksjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DUDisksJob_t {
    QByteArrayData data[24];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DUDisksJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DUDisksJob_t qt_meta_stringdata_DUDisksJob = {
    {
QT_MOC_LITERAL(0, 0, 10), // "DUDisksJob"
QT_MOC_LITERAL(1, 11, 9), // "completed"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 7), // "success"
QT_MOC_LITERAL(4, 30, 7), // "message"
QT_MOC_LITERAL(5, 38, 15), // "progressChanged"
QT_MOC_LITERAL(6, 54, 8), // "progress"
QT_MOC_LITERAL(7, 63, 11), // "rateChanged"
QT_MOC_LITERAL(8, 75, 4), // "rate"
QT_MOC_LITERAL(9, 80, 22), // "expectedEndTimeChanged"
QT_MOC_LITERAL(10, 103, 15), // "expectedEndTime"
QT_MOC_LITERAL(11, 119, 6), // "cancel"
QT_MOC_LITERAL(12, 126, 7), // "options"
QT_MOC_LITERAL(13, 134, 19), // "onPropertiesChanged"
QT_MOC_LITERAL(14, 154, 9), // "interface"
QT_MOC_LITERAL(15, 164, 18), // "changed_properties"
QT_MOC_LITERAL(16, 183, 4), // "path"
QT_MOC_LITERAL(17, 188, 7), // "objects"
QT_MOC_LITERAL(18, 196, 10), // "cancelable"
QT_MOC_LITERAL(19, 207, 13), // "progressValid"
QT_MOC_LITERAL(20, 221, 9), // "operation"
QT_MOC_LITERAL(21, 231, 12), // "startedByUid"
QT_MOC_LITERAL(22, 244, 5), // "bytes"
QT_MOC_LITERAL(23, 250, 9) // "startTime"

    },
    "DUDisksJob\0completed\0\0success\0message\0"
    "progressChanged\0progress\0rateChanged\0"
    "rate\0expectedEndTimeChanged\0expectedEndTime\0"
    "cancel\0options\0onPropertiesChanged\0"
    "interface\0changed_properties\0path\0"
    "objects\0cancelable\0progressValid\0"
    "operation\0startedByUid\0bytes\0startTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DUDisksJob[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
      11,   66, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x06 /* Public */,
       5,    1,   49,    2, 0x06 /* Public */,
       7,    1,   52,    2, 0x06 /* Public */,
       9,    1,   55,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,   58,    2, 0x0a /* Public */,
      13,    2,   61,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void, QMetaType::ULongLong,    8,
    QMetaType::Void, QMetaType::ULongLong,   10,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariantMap,   12,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   14,   15,

 // properties: name, type, flags
      16, QMetaType::QString, 0x00095c01,
      17, QMetaType::QStringList, 0x00095c01,
      18, QMetaType::Bool, 0x00095c01,
      19, QMetaType::Bool, 0x00095c01,
       6, QMetaType::Double, 0x00495801,
      20, QMetaType::QString, 0x00095c01,
      21, QMetaType::UInt, 0x00095c01,
      22, QMetaType::ULongLong, 0x00095c01,
      10, QMetaType::ULongLong, 0x00495801,
       8, QMetaType::ULongLong, 0x00495801,
      23, QMetaType::ULongLong, 0x00095c01,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       1,
       0,
       0,
       0,
       3,
       2,
       0,

       0        // eod
};

void DUDisksJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DUDisksJob *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->completed((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 1: _t->progressChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 2: _t->rateChanged((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 3: _t->expectedEndTimeChanged((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 4: _t->cancel((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 5: _t->onPropertiesChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DUDisksJob::*)(bool , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUDisksJob::completed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DUDisksJob::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUDisksJob::progressChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DUDisksJob::*)(quint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUDisksJob::rateChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DUDisksJob::*)(quint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUDisksJob::expectedEndTimeChanged)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DUDisksJob *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast< QStringList*>(_v) = _t->objects(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->cancelable(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->progressValid(); break;
        case 4: *reinterpret_cast< double*>(_v) = _t->progress(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->operation(); break;
        case 6: *reinterpret_cast< quint32*>(_v) = _t->startedByUid(); break;
        case 7: *reinterpret_cast< quint64*>(_v) = _t->bytes(); break;
        case 8: *reinterpret_cast< quint64*>(_v) = _t->expectedEndTime(); break;
        case 9: *reinterpret_cast< quint64*>(_v) = _t->rate(); break;
        case 10: *reinterpret_cast< quint64*>(_v) = _t->startTime(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DUDisksJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DUDisksJob.data,
    qt_meta_data_DUDisksJob,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DUDisksJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DUDisksJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DUDisksJob.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DUDisksJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DUDisksJob::completed(bool _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DUDisksJob::progressChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DUDisksJob::rateChanged(quint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DUDisksJob::expectedEndTimeChanged(quint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
