/****************************************************************************
** Meta object code from reading C++ file 'dblockpartition.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "dblockpartition.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dblockpartition.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBlockPartition_t {
    QByteArrayData data[232];
    char stringdata0[2947];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBlockPartition_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBlockPartition_t qt_meta_stringdata_DBlockPartition = {
    {
QT_MOC_LITERAL(0, 0, 15), // "DBlockPartition"
QT_MOC_LITERAL(1, 16, 12), // "flagsChanged"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 5), // "flags"
QT_MOC_LITERAL(4, 36, 18), // "isContainedChanged"
QT_MOC_LITERAL(5, 55, 11), // "isContained"
QT_MOC_LITERAL(6, 67, 18), // "isContainerChanged"
QT_MOC_LITERAL(7, 86, 11), // "isContainer"
QT_MOC_LITERAL(8, 98, 11), // "nameChanged"
QT_MOC_LITERAL(9, 110, 4), // "name"
QT_MOC_LITERAL(10, 115, 13), // "numberChanged"
QT_MOC_LITERAL(11, 129, 6), // "number"
QT_MOC_LITERAL(12, 136, 13), // "offsetChanged"
QT_MOC_LITERAL(13, 150, 6), // "offset"
QT_MOC_LITERAL(14, 157, 11), // "sizeChanged"
QT_MOC_LITERAL(15, 169, 4), // "size"
QT_MOC_LITERAL(16, 174, 11), // "typeChanged"
QT_MOC_LITERAL(17, 186, 4), // "type"
QT_MOC_LITERAL(18, 191, 12), // "eTypeChanged"
QT_MOC_LITERAL(19, 204, 11), // "UUIDChanged"
QT_MOC_LITERAL(20, 216, 4), // "UUID"
QT_MOC_LITERAL(21, 221, 15), // "guidTypeChanged"
QT_MOC_LITERAL(22, 237, 15), // "deletePartition"
QT_MOC_LITERAL(23, 253, 7), // "options"
QT_MOC_LITERAL(24, 261, 6), // "resize"
QT_MOC_LITERAL(25, 268, 8), // "setFlags"
QT_MOC_LITERAL(26, 277, 7), // "setName"
QT_MOC_LITERAL(27, 285, 7), // "setType"
QT_MOC_LITERAL(28, 293, 4), // "Type"
QT_MOC_LITERAL(29, 298, 5), // "table"
QT_MOC_LITERAL(30, 304, 5), // "eType"
QT_MOC_LITERAL(31, 310, 8), // "guidType"
QT_MOC_LITERAL(32, 319, 8), // "GUIDType"
QT_MOC_LITERAL(33, 328, 5), // "Empty"
QT_MOC_LITERAL(34, 334, 9), // "FAT12Type"
QT_MOC_LITERAL(35, 344, 10), // "XENIX_root"
QT_MOC_LITERAL(36, 355, 9), // "XENIX_usr"
QT_MOC_LITERAL(37, 365, 14), // "FAT16_Less_32M"
QT_MOC_LITERAL(38, 380, 8), // "Extended"
QT_MOC_LITERAL(39, 389, 9), // "FAT16Type"
QT_MOC_LITERAL(40, 399, 9), // "HPFS_NTFS"
QT_MOC_LITERAL(41, 409, 3), // "AIX"
QT_MOC_LITERAL(42, 413, 12), // "AIX_bootable"
QT_MOC_LITERAL(43, 426, 16), // "OS2_Boot_Manager"
QT_MOC_LITERAL(44, 443, 11), // "Win95_FAT32"
QT_MOC_LITERAL(45, 455, 15), // "Win95_FAT32_LBA"
QT_MOC_LITERAL(46, 471, 15), // "Win95_FAT16_LBA"
QT_MOC_LITERAL(47, 487, 18), // "Win95_Extended_LBA"
QT_MOC_LITERAL(48, 506, 4), // "OPUS"
QT_MOC_LITERAL(49, 511, 12), // "Hidden_FAT12"
QT_MOC_LITERAL(50, 524, 18), // "Compaq_diagnostics"
QT_MOC_LITERAL(51, 543, 21), // "Hidden_FAT16_Less_32M"
QT_MOC_LITERAL(52, 565, 12), // "Hidden_FAT16"
QT_MOC_LITERAL(53, 578, 19), // "Hidden_HPFS_or_NTFS"
QT_MOC_LITERAL(54, 598, 14), // "AST_SmartSleep"
QT_MOC_LITERAL(55, 613, 18), // "Hidden_Win95_FAT32"
QT_MOC_LITERAL(56, 632, 22), // "Hidden_Win95_FAT32_LBA"
QT_MOC_LITERAL(57, 655, 22), // "Hidden_Win95_FAT16_LBA"
QT_MOC_LITERAL(58, 678, 7), // "NEC_DOS"
QT_MOC_LITERAL(59, 686, 5), // "Plan9"
QT_MOC_LITERAL(60, 692, 23), // "PartitionMagic_recovery"
QT_MOC_LITERAL(61, 716, 11), // "Venix_80286"
QT_MOC_LITERAL(62, 728, 13), // "PPC_PReP_Boot"
QT_MOC_LITERAL(63, 742, 3), // "SFS"
QT_MOC_LITERAL(64, 746, 10), // "QNX4_dot_x"
QT_MOC_LITERAL(65, 757, 19), // "QNX4_dot_x_2nd_part"
QT_MOC_LITERAL(66, 777, 19), // "QNX4_dot_x_3rd_part"
QT_MOC_LITERAL(67, 797, 10), // "OnTrack_DM"
QT_MOC_LITERAL(68, 808, 16), // "OnTrack_DM6_Aux1"
QT_MOC_LITERAL(69, 825, 4), // "CP_M"
QT_MOC_LITERAL(70, 830, 16), // "OnTrack_DM6_Aux3"
QT_MOC_LITERAL(71, 847, 10), // "OnTrackDM6"
QT_MOC_LITERAL(72, 858, 8), // "EZ_Drive"
QT_MOC_LITERAL(73, 867, 10), // "Golden_Bow"
QT_MOC_LITERAL(74, 878, 11), // "Priam_Edisk"
QT_MOC_LITERAL(75, 890, 9), // "SpeedStor"
QT_MOC_LITERAL(76, 900, 16), // "GNU_HURD_or_SysV"
QT_MOC_LITERAL(77, 917, 18), // "Novell_Netware_286"
QT_MOC_LITERAL(78, 936, 18), // "Novell_Netware_386"
QT_MOC_LITERAL(79, 955, 21), // "DiskSecure_Multi_Boot"
QT_MOC_LITERAL(80, 977, 5), // "PC_IX"
QT_MOC_LITERAL(81, 983, 9), // "Old_Minix"
QT_MOC_LITERAL(82, 993, 15), // "Minix_old_Linux"
QT_MOC_LITERAL(83, 1009, 10), // "Linux_swap"
QT_MOC_LITERAL(84, 1020, 5), // "Linux"
QT_MOC_LITERAL(85, 1026, 18), // "OS2_hidden_C_drive"
QT_MOC_LITERAL(86, 1045, 14), // "Linux_extended"
QT_MOC_LITERAL(87, 1060, 17), // "NTFS_volume_set_1"
QT_MOC_LITERAL(88, 1078, 17), // "NTFS_volume_set_2"
QT_MOC_LITERAL(89, 1096, 9), // "Linux_LVM"
QT_MOC_LITERAL(90, 1106, 6), // "Amoeba"
QT_MOC_LITERAL(91, 1113, 10), // "Amoeba_BBT"
QT_MOC_LITERAL(92, 1124, 6), // "BSD_OS"
QT_MOC_LITERAL(93, 1131, 24), // "IBM_Thinkpad_hibernation"
QT_MOC_LITERAL(94, 1156, 7), // "FreeBSD"
QT_MOC_LITERAL(95, 1164, 7), // "OpenBSD"
QT_MOC_LITERAL(96, 1172, 8), // "NeXTSTEP"
QT_MOC_LITERAL(97, 1181, 6), // "NetBSD"
QT_MOC_LITERAL(98, 1188, 7), // "BSDI_fs"
QT_MOC_LITERAL(99, 1196, 9), // "BSDI_swap"
QT_MOC_LITERAL(100, 1206, 18), // "Boot_Wizard_hidden"
QT_MOC_LITERAL(101, 1225, 15), // "DRDOS_sec_FAT12"
QT_MOC_LITERAL(102, 1241, 24), // "DRDOS_sec_FAT16_Less_32M"
QT_MOC_LITERAL(103, 1266, 15), // "DRDOS_sec_FAT16"
QT_MOC_LITERAL(104, 1282, 16), // "DRDOS_sec_extend"
QT_MOC_LITERAL(105, 1299, 6), // "Syrinx"
QT_MOC_LITERAL(106, 1306, 11), // "Non_FS_data"
QT_MOC_LITERAL(107, 1318, 20), // "Multiuser_DOS_extend"
QT_MOC_LITERAL(108, 1339, 21), // "CP_M_CTOS_dot_dot_dot"
QT_MOC_LITERAL(109, 1361, 12), // "Dell_Utility"
QT_MOC_LITERAL(110, 1374, 6), // "BootIt"
QT_MOC_LITERAL(111, 1381, 10), // "DOS_access"
QT_MOC_LITERAL(112, 1392, 7), // "DOS_R_O"
QT_MOC_LITERAL(113, 1400, 11), // "SpeedStor_1"
QT_MOC_LITERAL(114, 1412, 7), // "BeOS_fs"
QT_MOC_LITERAL(115, 1420, 7), // "EFI_GPT"
QT_MOC_LITERAL(116, 1428, 15), // "EFI_FAT12_16_32"
QT_MOC_LITERAL(117, 1444, 18), // "Linux_PA_RISC_boot"
QT_MOC_LITERAL(118, 1463, 11), // "SpeedStor_2"
QT_MOC_LITERAL(119, 1475, 11), // "SeppdStor_3"
QT_MOC_LITERAL(120, 1487, 13), // "DOS_secondary"
QT_MOC_LITERAL(121, 1501, 21), // "Linux_raid_autodetect"
QT_MOC_LITERAL(122, 1523, 7), // "LANstep"
QT_MOC_LITERAL(123, 1531, 3), // "BBT"
QT_MOC_LITERAL(124, 1535, 6), // "Unknow"
QT_MOC_LITERAL(125, 1542, 11), // "InvalidUUID"
QT_MOC_LITERAL(126, 1554, 13), // "GUIDTypeBegin"
QT_MOC_LITERAL(127, 1568, 11), // "Unused_None"
QT_MOC_LITERAL(128, 1580, 11), // "MBR_PS_None"
QT_MOC_LITERAL(129, 1592, 11), // "EFI_SP_None"
QT_MOC_LITERAL(130, 1604, 12), // "BIOS_BP_None"
QT_MOC_LITERAL(131, 1617, 9), // "iFFS_None"
QT_MOC_LITERAL(132, 1627, 12), // "Sony_BP_None"
QT_MOC_LITERAL(133, 1640, 14), // "Lenove_BP_None"
QT_MOC_LITERAL(134, 1655, 7), // "MSR_Win"
QT_MOC_LITERAL(135, 1663, 13), // "BasicData_Win"
QT_MOC_LITERAL(136, 1677, 7), // "LDM_Win"
QT_MOC_LITERAL(137, 1685, 10), // "LDM_DP_Win"
QT_MOC_LITERAL(138, 1696, 7), // "WRE_Win"
QT_MOC_LITERAL(139, 1704, 12), // "IBM_GPFS_Win"
QT_MOC_LITERAL(140, 1717, 7), // "SSP_Win"
QT_MOC_LITERAL(141, 1725, 7), // "DP_HPUX"
QT_MOC_LITERAL(142, 1733, 7), // "SP_HPUX"
QT_MOC_LITERAL(143, 1741, 9), // "LFD_Linux"
QT_MOC_LITERAL(144, 1751, 12), // "RAID_P_Linux"
QT_MOC_LITERAL(145, 1764, 12), // "RP_x86_Linux"
QT_MOC_LITERAL(146, 1777, 15), // "RP_x86_64_Linux"
QT_MOC_LITERAL(147, 1793, 18), // "RP_32bit_ARM_Linux"
QT_MOC_LITERAL(148, 1812, 18), // "RP_64bit_ARM_Linux"
QT_MOC_LITERAL(149, 1831, 8), // "SP_Linux"
QT_MOC_LITERAL(150, 1840, 11), // "LVM_P_Linux"
QT_MOC_LITERAL(151, 1852, 12), // "Home_P_Linux"
QT_MOC_LITERAL(152, 1865, 11), // "Srv_P_Linux"
QT_MOC_LITERAL(153, 1877, 16), // "Plain_DC_P_Linux"
QT_MOC_LITERAL(154, 1894, 12), // "LUKS_P_Linux"
QT_MOC_LITERAL(155, 1907, 14), // "Reserved_Linux"
QT_MOC_LITERAL(156, 1922, 10), // "BP_FreeBSD"
QT_MOC_LITERAL(157, 1933, 10), // "DP_FreeBSD"
QT_MOC_LITERAL(158, 1944, 10), // "SP_FreeBSD"
QT_MOC_LITERAL(159, 1955, 13), // "UFS_P_FreeBSD"
QT_MOC_LITERAL(160, 1969, 13), // "VVM_P_FreeBSD"
QT_MOC_LITERAL(161, 1983, 13), // "ZFS_P_FreeBSD"
QT_MOC_LITERAL(162, 1997, 14), // "HFS_PLUS_P_Mac"
QT_MOC_LITERAL(163, 2012, 7), // "UFS_Mac"
QT_MOC_LITERAL(164, 2020, 7), // "ZFS_Mac"
QT_MOC_LITERAL(165, 2028, 10), // "RAID_P_Mac"
QT_MOC_LITERAL(166, 2039, 18), // "RAID_P_Offline_Mac"
QT_MOC_LITERAL(167, 2058, 6), // "BP_Mac"
QT_MOC_LITERAL(168, 2065, 9), // "Label_Mac"
QT_MOC_LITERAL(169, 2075, 9), // "TV_RP_Mac"
QT_MOC_LITERAL(170, 2085, 8), // "CS_P_Mac"
QT_MOC_LITERAL(171, 2094, 19), // "SoftRAID_Status_Mac"
QT_MOC_LITERAL(172, 2114, 20), // "SoftRAID_Scratch_Mac"
QT_MOC_LITERAL(173, 2135, 19), // "SoftRAID_Volume_Mac"
QT_MOC_LITERAL(174, 2155, 18), // "SoftRAID_Cache_Mac"
QT_MOC_LITERAL(175, 2174, 10), // "BP_Solaris"
QT_MOC_LITERAL(176, 2185, 10), // "RP_Solaris"
QT_MOC_LITERAL(177, 2196, 10), // "SP_Solaris"
QT_MOC_LITERAL(178, 2207, 16), // "Backup_P_Solaris"
QT_MOC_LITERAL(179, 2224, 13), // "Usr_P_Solaris"
QT_MOC_LITERAL(180, 2238, 13), // "Var_P_Solaris"
QT_MOC_LITERAL(181, 2252, 14), // "Home_P_Solaris"
QT_MOC_LITERAL(182, 2267, 10), // "AS_Solaris"
QT_MOC_LITERAL(183, 2278, 16), // "Reserved_Solaris"
QT_MOC_LITERAL(184, 2295, 9), // "SP_NetBSD"
QT_MOC_LITERAL(185, 2305, 12), // "FFS_P_NetBSD"
QT_MOC_LITERAL(186, 2318, 12), // "LFS_P_NetBSD"
QT_MOC_LITERAL(187, 2331, 13), // "RAID_P_NetBSD"
QT_MOC_LITERAL(188, 2345, 9), // "CP_NetBSD"
QT_MOC_LITERAL(189, 2355, 9), // "EP_NetBSD"
QT_MOC_LITERAL(190, 2365, 15), // "Kernel_ChromeOS"
QT_MOC_LITERAL(191, 2381, 15), // "Rootfs_ChromeOS"
QT_MOC_LITERAL(192, 2397, 11), // "FU_ChromeOS"
QT_MOC_LITERAL(193, 2409, 9), // "BFS_Haiku"
QT_MOC_LITERAL(194, 2419, 14), // "BP_MidnightBSD"
QT_MOC_LITERAL(195, 2434, 14), // "DP_MidnightBSD"
QT_MOC_LITERAL(196, 2449, 14), // "SP_MidnightBSD"
QT_MOC_LITERAL(197, 2464, 17), // "UFS_P_MidnightBSD"
QT_MOC_LITERAL(198, 2482, 17), // "VVM_P_MidnightBSD"
QT_MOC_LITERAL(199, 2500, 17), // "ZFS_P_MidnightBSD"
QT_MOC_LITERAL(200, 2518, 12), // "Journal_Ceph"
QT_MOC_LITERAL(201, 2531, 10), // "DC_EJ_Ceph"
QT_MOC_LITERAL(202, 2542, 8), // "OSD_Ceph"
QT_MOC_LITERAL(203, 2551, 11), // "DC_OSD_Ceph"
QT_MOC_LITERAL(204, 2563, 8), // "DIC_Ceph"
QT_MOC_LITERAL(205, 2572, 11), // "DC_DIC_Ceph"
QT_MOC_LITERAL(206, 2584, 10), // "DP_OpenBSD"
QT_MOC_LITERAL(207, 2595, 8), // "PAFS_QNX"
QT_MOC_LITERAL(208, 2604, 15), // "Partition_Plan9"
QT_MOC_LITERAL(209, 2620, 14), // "Vmkcore_VMware"
QT_MOC_LITERAL(210, 2635, 11), // "VMFS_VMware"
QT_MOC_LITERAL(211, 2647, 15), // "Reserved_VMware"
QT_MOC_LITERAL(212, 2663, 18), // "Bootloader_Android"
QT_MOC_LITERAL(213, 2682, 19), // "Bottloader2_Android"
QT_MOC_LITERAL(214, 2702, 12), // "Boot_Android"
QT_MOC_LITERAL(215, 2715, 16), // "Recovery_Android"
QT_MOC_LITERAL(216, 2732, 12), // "Misc_Android"
QT_MOC_LITERAL(217, 2745, 16), // "Metadata_Android"
QT_MOC_LITERAL(218, 2762, 14), // "System_Android"
QT_MOC_LITERAL(219, 2777, 13), // "Cache_Android"
QT_MOC_LITERAL(220, 2791, 12), // "Data_Android"
QT_MOC_LITERAL(221, 2804, 18), // "Persistent_Android"
QT_MOC_LITERAL(222, 2823, 15), // "Factory_Android"
QT_MOC_LITERAL(223, 2839, 16), // "Fastboot_Android"
QT_MOC_LITERAL(224, 2856, 11), // "OEM_Android"
QT_MOC_LITERAL(225, 2868, 9), // "Boot_ONIE"
QT_MOC_LITERAL(226, 2878, 11), // "Config_ONIE"
QT_MOC_LITERAL(227, 2890, 12), // "Boot_PowerPC"
QT_MOC_LITERAL(228, 2903, 9), // "SBLC_OSes"
QT_MOC_LITERAL(229, 2913, 10), // "BD_P_Atari"
QT_MOC_LITERAL(230, 2924, 11), // "GUIDTypeEnd"
QT_MOC_LITERAL(231, 2936, 10) // "UnknowUUID"

    },
    "DBlockPartition\0flagsChanged\0\0flags\0"
    "isContainedChanged\0isContained\0"
    "isContainerChanged\0isContainer\0"
    "nameChanged\0name\0numberChanged\0number\0"
    "offsetChanged\0offset\0sizeChanged\0size\0"
    "typeChanged\0type\0eTypeChanged\0UUIDChanged\0"
    "UUID\0guidTypeChanged\0deletePartition\0"
    "options\0resize\0setFlags\0setName\0setType\0"
    "Type\0table\0eType\0guidType\0GUIDType\0"
    "Empty\0FAT12Type\0XENIX_root\0XENIX_usr\0"
    "FAT16_Less_32M\0Extended\0FAT16Type\0"
    "HPFS_NTFS\0AIX\0AIX_bootable\0OS2_Boot_Manager\0"
    "Win95_FAT32\0Win95_FAT32_LBA\0Win95_FAT16_LBA\0"
    "Win95_Extended_LBA\0OPUS\0Hidden_FAT12\0"
    "Compaq_diagnostics\0Hidden_FAT16_Less_32M\0"
    "Hidden_FAT16\0Hidden_HPFS_or_NTFS\0"
    "AST_SmartSleep\0Hidden_Win95_FAT32\0"
    "Hidden_Win95_FAT32_LBA\0Hidden_Win95_FAT16_LBA\0"
    "NEC_DOS\0Plan9\0PartitionMagic_recovery\0"
    "Venix_80286\0PPC_PReP_Boot\0SFS\0QNX4_dot_x\0"
    "QNX4_dot_x_2nd_part\0QNX4_dot_x_3rd_part\0"
    "OnTrack_DM\0OnTrack_DM6_Aux1\0CP_M\0"
    "OnTrack_DM6_Aux3\0OnTrackDM6\0EZ_Drive\0"
    "Golden_Bow\0Priam_Edisk\0SpeedStor\0"
    "GNU_HURD_or_SysV\0Novell_Netware_286\0"
    "Novell_Netware_386\0DiskSecure_Multi_Boot\0"
    "PC_IX\0Old_Minix\0Minix_old_Linux\0"
    "Linux_swap\0Linux\0OS2_hidden_C_drive\0"
    "Linux_extended\0NTFS_volume_set_1\0"
    "NTFS_volume_set_2\0Linux_LVM\0Amoeba\0"
    "Amoeba_BBT\0BSD_OS\0IBM_Thinkpad_hibernation\0"
    "FreeBSD\0OpenBSD\0NeXTSTEP\0NetBSD\0BSDI_fs\0"
    "BSDI_swap\0Boot_Wizard_hidden\0"
    "DRDOS_sec_FAT12\0DRDOS_sec_FAT16_Less_32M\0"
    "DRDOS_sec_FAT16\0DRDOS_sec_extend\0"
    "Syrinx\0Non_FS_data\0Multiuser_DOS_extend\0"
    "CP_M_CTOS_dot_dot_dot\0Dell_Utility\0"
    "BootIt\0DOS_access\0DOS_R_O\0SpeedStor_1\0"
    "BeOS_fs\0EFI_GPT\0EFI_FAT12_16_32\0"
    "Linux_PA_RISC_boot\0SpeedStor_2\0"
    "SeppdStor_3\0DOS_secondary\0"
    "Linux_raid_autodetect\0LANstep\0BBT\0"
    "Unknow\0InvalidUUID\0GUIDTypeBegin\0"
    "Unused_None\0MBR_PS_None\0EFI_SP_None\0"
    "BIOS_BP_None\0iFFS_None\0Sony_BP_None\0"
    "Lenove_BP_None\0MSR_Win\0BasicData_Win\0"
    "LDM_Win\0LDM_DP_Win\0WRE_Win\0IBM_GPFS_Win\0"
    "SSP_Win\0DP_HPUX\0SP_HPUX\0LFD_Linux\0"
    "RAID_P_Linux\0RP_x86_Linux\0RP_x86_64_Linux\0"
    "RP_32bit_ARM_Linux\0RP_64bit_ARM_Linux\0"
    "SP_Linux\0LVM_P_Linux\0Home_P_Linux\0"
    "Srv_P_Linux\0Plain_DC_P_Linux\0LUKS_P_Linux\0"
    "Reserved_Linux\0BP_FreeBSD\0DP_FreeBSD\0"
    "SP_FreeBSD\0UFS_P_FreeBSD\0VVM_P_FreeBSD\0"
    "ZFS_P_FreeBSD\0HFS_PLUS_P_Mac\0UFS_Mac\0"
    "ZFS_Mac\0RAID_P_Mac\0RAID_P_Offline_Mac\0"
    "BP_Mac\0Label_Mac\0TV_RP_Mac\0CS_P_Mac\0"
    "SoftRAID_Status_Mac\0SoftRAID_Scratch_Mac\0"
    "SoftRAID_Volume_Mac\0SoftRAID_Cache_Mac\0"
    "BP_Solaris\0RP_Solaris\0SP_Solaris\0"
    "Backup_P_Solaris\0Usr_P_Solaris\0"
    "Var_P_Solaris\0Home_P_Solaris\0AS_Solaris\0"
    "Reserved_Solaris\0SP_NetBSD\0FFS_P_NetBSD\0"
    "LFS_P_NetBSD\0RAID_P_NetBSD\0CP_NetBSD\0"
    "EP_NetBSD\0Kernel_ChromeOS\0Rootfs_ChromeOS\0"
    "FU_ChromeOS\0BFS_Haiku\0BP_MidnightBSD\0"
    "DP_MidnightBSD\0SP_MidnightBSD\0"
    "UFS_P_MidnightBSD\0VVM_P_MidnightBSD\0"
    "ZFS_P_MidnightBSD\0Journal_Ceph\0"
    "DC_EJ_Ceph\0OSD_Ceph\0DC_OSD_Ceph\0"
    "DIC_Ceph\0DC_DIC_Ceph\0DP_OpenBSD\0"
    "PAFS_QNX\0Partition_Plan9\0Vmkcore_VMware\0"
    "VMFS_VMware\0Reserved_VMware\0"
    "Bootloader_Android\0Bottloader2_Android\0"
    "Boot_Android\0Recovery_Android\0"
    "Misc_Android\0Metadata_Android\0"
    "System_Android\0Cache_Android\0Data_Android\0"
    "Persistent_Android\0Factory_Android\0"
    "Fastboot_Android\0OEM_Android\0Boot_ONIE\0"
    "Config_ONIE\0Boot_PowerPC\0SBLC_OSes\0"
    "BD_P_Atari\0GUIDTypeEnd\0UnknowUUID"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBlockPartition[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
      12,  156, // properties
       2,  204, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       4,    1,  102,    2, 0x06 /* Public */,
       6,    1,  105,    2, 0x06 /* Public */,
       8,    1,  108,    2, 0x06 /* Public */,
      10,    1,  111,    2, 0x06 /* Public */,
      12,    1,  114,    2, 0x06 /* Public */,
      14,    1,  117,    2, 0x06 /* Public */,
      16,    1,  120,    2, 0x06 /* Public */,
      18,    0,  123,    2, 0x06 /* Public */,
      19,    1,  124,    2, 0x06 /* Public */,
      21,    0,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      22,    1,  128,    2, 0x0a /* Public */,
      24,    2,  131,    2, 0x0a /* Public */,
      25,    2,  136,    2, 0x0a /* Public */,
      26,    2,  141,    2, 0x0a /* Public */,
      27,    2,  146,    2, 0x0a /* Public */,
      27,    2,  151,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::UInt,   11,
    QMetaType::Void, QMetaType::ULongLong,   13,
    QMetaType::Void, QMetaType::ULongLong,   15,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariantMap,   23,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QVariantMap,   15,   23,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QVariantMap,    3,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,    9,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   17,   23,
    QMetaType::Void, 0x80000000 | 28, QMetaType::QVariantMap,   17,   23,

 // properties: name, type, flags
       3, QMetaType::ULongLong, 0x00495001,
       5, QMetaType::Bool, 0x00495001,
       7, QMetaType::Bool, 0x00495001,
       9, QMetaType::QString, 0x00495001,
      11, QMetaType::UInt, 0x00495001,
      13, QMetaType::ULongLong, 0x00495001,
      15, QMetaType::ULongLong, 0x00495001,
      29, QMetaType::QString, 0x00095001,
      17, QMetaType::QString, 0x00495001,
      30, 0x80000000 | 28, 0x00495009,
      31, 0x80000000 | 32, 0x00495009,
      20, QMetaType::QString, 0x00495001,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       0,
       7,
       8,
      10,
       9,

 // enums: name, alias, flags, count, data
      28,   28, 0x0,   92,  214,
      32,   32, 0x0,  107,  398,

 // enum data: key, value
      33, uint(DBlockPartition::Empty),
      34, uint(DBlockPartition::FAT12Type),
      35, uint(DBlockPartition::XENIX_root),
      36, uint(DBlockPartition::XENIX_usr),
      37, uint(DBlockPartition::FAT16_Less_32M),
      38, uint(DBlockPartition::Extended),
      39, uint(DBlockPartition::FAT16Type),
      40, uint(DBlockPartition::HPFS_NTFS),
      41, uint(DBlockPartition::AIX),
      42, uint(DBlockPartition::AIX_bootable),
      43, uint(DBlockPartition::OS2_Boot_Manager),
      44, uint(DBlockPartition::Win95_FAT32),
      45, uint(DBlockPartition::Win95_FAT32_LBA),
      46, uint(DBlockPartition::Win95_FAT16_LBA),
      47, uint(DBlockPartition::Win95_Extended_LBA),
      48, uint(DBlockPartition::OPUS),
      49, uint(DBlockPartition::Hidden_FAT12),
      50, uint(DBlockPartition::Compaq_diagnostics),
      51, uint(DBlockPartition::Hidden_FAT16_Less_32M),
      52, uint(DBlockPartition::Hidden_FAT16),
      53, uint(DBlockPartition::Hidden_HPFS_or_NTFS),
      54, uint(DBlockPartition::AST_SmartSleep),
      55, uint(DBlockPartition::Hidden_Win95_FAT32),
      56, uint(DBlockPartition::Hidden_Win95_FAT32_LBA),
      57, uint(DBlockPartition::Hidden_Win95_FAT16_LBA),
      58, uint(DBlockPartition::NEC_DOS),
      59, uint(DBlockPartition::Plan9),
      60, uint(DBlockPartition::PartitionMagic_recovery),
      61, uint(DBlockPartition::Venix_80286),
      62, uint(DBlockPartition::PPC_PReP_Boot),
      63, uint(DBlockPartition::SFS),
      64, uint(DBlockPartition::QNX4_dot_x),
      65, uint(DBlockPartition::QNX4_dot_x_2nd_part),
      66, uint(DBlockPartition::QNX4_dot_x_3rd_part),
      67, uint(DBlockPartition::OnTrack_DM),
      68, uint(DBlockPartition::OnTrack_DM6_Aux1),
      69, uint(DBlockPartition::CP_M),
      70, uint(DBlockPartition::OnTrack_DM6_Aux3),
      71, uint(DBlockPartition::OnTrackDM6),
      72, uint(DBlockPartition::EZ_Drive),
      73, uint(DBlockPartition::Golden_Bow),
      74, uint(DBlockPartition::Priam_Edisk),
      75, uint(DBlockPartition::SpeedStor),
      76, uint(DBlockPartition::GNU_HURD_or_SysV),
      77, uint(DBlockPartition::Novell_Netware_286),
      78, uint(DBlockPartition::Novell_Netware_386),
      79, uint(DBlockPartition::DiskSecure_Multi_Boot),
      80, uint(DBlockPartition::PC_IX),
      81, uint(DBlockPartition::Old_Minix),
      82, uint(DBlockPartition::Minix_old_Linux),
      83, uint(DBlockPartition::Linux_swap),
      84, uint(DBlockPartition::Linux),
      85, uint(DBlockPartition::OS2_hidden_C_drive),
      86, uint(DBlockPartition::Linux_extended),
      87, uint(DBlockPartition::NTFS_volume_set_1),
      88, uint(DBlockPartition::NTFS_volume_set_2),
      89, uint(DBlockPartition::Linux_LVM),
      90, uint(DBlockPartition::Amoeba),
      91, uint(DBlockPartition::Amoeba_BBT),
      92, uint(DBlockPartition::BSD_OS),
      93, uint(DBlockPartition::IBM_Thinkpad_hibernation),
      94, uint(DBlockPartition::FreeBSD),
      95, uint(DBlockPartition::OpenBSD),
      96, uint(DBlockPartition::NeXTSTEP),
      97, uint(DBlockPartition::NetBSD),
      98, uint(DBlockPartition::BSDI_fs),
      99, uint(DBlockPartition::BSDI_swap),
     100, uint(DBlockPartition::Boot_Wizard_hidden),
     101, uint(DBlockPartition::DRDOS_sec_FAT12),
     102, uint(DBlockPartition::DRDOS_sec_FAT16_Less_32M),
     103, uint(DBlockPartition::DRDOS_sec_FAT16),
     104, uint(DBlockPartition::DRDOS_sec_extend),
     105, uint(DBlockPartition::Syrinx),
     106, uint(DBlockPartition::Non_FS_data),
     107, uint(DBlockPartition::Multiuser_DOS_extend),
     108, uint(DBlockPartition::CP_M_CTOS_dot_dot_dot),
     109, uint(DBlockPartition::Dell_Utility),
     110, uint(DBlockPartition::BootIt),
     111, uint(DBlockPartition::DOS_access),
     112, uint(DBlockPartition::DOS_R_O),
     113, uint(DBlockPartition::SpeedStor_1),
     114, uint(DBlockPartition::BeOS_fs),
     115, uint(DBlockPartition::EFI_GPT),
     116, uint(DBlockPartition::EFI_FAT12_16_32),
     117, uint(DBlockPartition::Linux_PA_RISC_boot),
     118, uint(DBlockPartition::SpeedStor_2),
     119, uint(DBlockPartition::SeppdStor_3),
     120, uint(DBlockPartition::DOS_secondary),
     121, uint(DBlockPartition::Linux_raid_autodetect),
     122, uint(DBlockPartition::LANstep),
     123, uint(DBlockPartition::BBT),
     124, uint(DBlockPartition::Unknow),
     125, uint(DBlockPartition::InvalidUUID),
     126, uint(DBlockPartition::GUIDTypeBegin),
     127, uint(DBlockPartition::Unused_None),
     128, uint(DBlockPartition::MBR_PS_None),
     129, uint(DBlockPartition::EFI_SP_None),
     130, uint(DBlockPartition::BIOS_BP_None),
     131, uint(DBlockPartition::iFFS_None),
     132, uint(DBlockPartition::Sony_BP_None),
     133, uint(DBlockPartition::Lenove_BP_None),
     134, uint(DBlockPartition::MSR_Win),
     135, uint(DBlockPartition::BasicData_Win),
     136, uint(DBlockPartition::LDM_Win),
     137, uint(DBlockPartition::LDM_DP_Win),
     138, uint(DBlockPartition::WRE_Win),
     139, uint(DBlockPartition::IBM_GPFS_Win),
     140, uint(DBlockPartition::SSP_Win),
     141, uint(DBlockPartition::DP_HPUX),
     142, uint(DBlockPartition::SP_HPUX),
     143, uint(DBlockPartition::LFD_Linux),
     144, uint(DBlockPartition::RAID_P_Linux),
     145, uint(DBlockPartition::RP_x86_Linux),
     146, uint(DBlockPartition::RP_x86_64_Linux),
     147, uint(DBlockPartition::RP_32bit_ARM_Linux),
     148, uint(DBlockPartition::RP_64bit_ARM_Linux),
     149, uint(DBlockPartition::SP_Linux),
     150, uint(DBlockPartition::LVM_P_Linux),
     151, uint(DBlockPartition::Home_P_Linux),
     152, uint(DBlockPartition::Srv_P_Linux),
     153, uint(DBlockPartition::Plain_DC_P_Linux),
     154, uint(DBlockPartition::LUKS_P_Linux),
     155, uint(DBlockPartition::Reserved_Linux),
     156, uint(DBlockPartition::BP_FreeBSD),
     157, uint(DBlockPartition::DP_FreeBSD),
     158, uint(DBlockPartition::SP_FreeBSD),
     159, uint(DBlockPartition::UFS_P_FreeBSD),
     160, uint(DBlockPartition::VVM_P_FreeBSD),
     161, uint(DBlockPartition::ZFS_P_FreeBSD),
     162, uint(DBlockPartition::HFS_PLUS_P_Mac),
     163, uint(DBlockPartition::UFS_Mac),
     164, uint(DBlockPartition::ZFS_Mac),
     165, uint(DBlockPartition::RAID_P_Mac),
     166, uint(DBlockPartition::RAID_P_Offline_Mac),
     167, uint(DBlockPartition::BP_Mac),
     168, uint(DBlockPartition::Label_Mac),
     169, uint(DBlockPartition::TV_RP_Mac),
     170, uint(DBlockPartition::CS_P_Mac),
     171, uint(DBlockPartition::SoftRAID_Status_Mac),
     172, uint(DBlockPartition::SoftRAID_Scratch_Mac),
     173, uint(DBlockPartition::SoftRAID_Volume_Mac),
     174, uint(DBlockPartition::SoftRAID_Cache_Mac),
     175, uint(DBlockPartition::BP_Solaris),
     176, uint(DBlockPartition::RP_Solaris),
     177, uint(DBlockPartition::SP_Solaris),
     178, uint(DBlockPartition::Backup_P_Solaris),
     179, uint(DBlockPartition::Usr_P_Solaris),
     180, uint(DBlockPartition::Var_P_Solaris),
     181, uint(DBlockPartition::Home_P_Solaris),
     182, uint(DBlockPartition::AS_Solaris),
     183, uint(DBlockPartition::Reserved_Solaris),
     184, uint(DBlockPartition::SP_NetBSD),
     185, uint(DBlockPartition::FFS_P_NetBSD),
     186, uint(DBlockPartition::LFS_P_NetBSD),
     187, uint(DBlockPartition::RAID_P_NetBSD),
     188, uint(DBlockPartition::CP_NetBSD),
     189, uint(DBlockPartition::EP_NetBSD),
     190, uint(DBlockPartition::Kernel_ChromeOS),
     191, uint(DBlockPartition::Rootfs_ChromeOS),
     192, uint(DBlockPartition::FU_ChromeOS),
     193, uint(DBlockPartition::BFS_Haiku),
     194, uint(DBlockPartition::BP_MidnightBSD),
     195, uint(DBlockPartition::DP_MidnightBSD),
     196, uint(DBlockPartition::SP_MidnightBSD),
     197, uint(DBlockPartition::UFS_P_MidnightBSD),
     198, uint(DBlockPartition::VVM_P_MidnightBSD),
     199, uint(DBlockPartition::ZFS_P_MidnightBSD),
     200, uint(DBlockPartition::Journal_Ceph),
     201, uint(DBlockPartition::DC_EJ_Ceph),
     202, uint(DBlockPartition::OSD_Ceph),
     203, uint(DBlockPartition::DC_OSD_Ceph),
     204, uint(DBlockPartition::DIC_Ceph),
     205, uint(DBlockPartition::DC_DIC_Ceph),
     206, uint(DBlockPartition::DP_OpenBSD),
     207, uint(DBlockPartition::PAFS_QNX),
     208, uint(DBlockPartition::Partition_Plan9),
     209, uint(DBlockPartition::Vmkcore_VMware),
     210, uint(DBlockPartition::VMFS_VMware),
     211, uint(DBlockPartition::Reserved_VMware),
     212, uint(DBlockPartition::Bootloader_Android),
     213, uint(DBlockPartition::Bottloader2_Android),
     214, uint(DBlockPartition::Boot_Android),
     215, uint(DBlockPartition::Recovery_Android),
     216, uint(DBlockPartition::Misc_Android),
     217, uint(DBlockPartition::Metadata_Android),
     218, uint(DBlockPartition::System_Android),
     219, uint(DBlockPartition::Cache_Android),
     220, uint(DBlockPartition::Data_Android),
     221, uint(DBlockPartition::Persistent_Android),
     222, uint(DBlockPartition::Factory_Android),
     223, uint(DBlockPartition::Fastboot_Android),
     224, uint(DBlockPartition::OEM_Android),
     225, uint(DBlockPartition::Boot_ONIE),
     226, uint(DBlockPartition::Config_ONIE),
     227, uint(DBlockPartition::Boot_PowerPC),
     228, uint(DBlockPartition::SBLC_OSes),
     229, uint(DBlockPartition::BD_P_Atari),
     230, uint(DBlockPartition::GUIDTypeEnd),
     231, uint(DBlockPartition::UnknowUUID),

       0        // eod
};

void DBlockPartition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DBlockPartition *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->flagsChanged((*reinterpret_cast< qulonglong(*)>(_a[1]))); break;
        case 1: _t->isContainedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->isContainerChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->nameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->numberChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->offsetChanged((*reinterpret_cast< qulonglong(*)>(_a[1]))); break;
        case 6: _t->sizeChanged((*reinterpret_cast< qulonglong(*)>(_a[1]))); break;
        case 7: _t->typeChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->eTypeChanged(); break;
        case 9: _t->UUIDChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->guidTypeChanged(); break;
        case 11: _t->deletePartition((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 12: _t->resize((*reinterpret_cast< qulonglong(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 13: _t->setFlags((*reinterpret_cast< qulonglong(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 14: _t->setName((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 15: _t->setType((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 16: _t->setType((*reinterpret_cast< Type(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DBlockPartition::*)(qulonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::flagsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::isContainedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::isContainerChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::nameChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::numberChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(qulonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::offsetChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(qulonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::sizeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::typeChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::eTypeChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::UUIDChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DBlockPartition::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlockPartition::guidTypeChanged)) {
                *result = 10;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DBlockPartition *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qulonglong*>(_v) = _t->flags(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isContained(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isContainer(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast< uint*>(_v) = _t->number(); break;
        case 5: *reinterpret_cast< qulonglong*>(_v) = _t->offset(); break;
        case 6: *reinterpret_cast< qulonglong*>(_v) = _t->size(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->table(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->type(); break;
        case 9: *reinterpret_cast< Type*>(_v) = _t->eType(); break;
        case 10: *reinterpret_cast< GUIDType*>(_v) = _t->guidType(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->UUID(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DBlockPartition::staticMetaObject = { {
    QMetaObject::SuperData::link<DBlockDevice::staticMetaObject>(),
    qt_meta_stringdata_DBlockPartition.data,
    qt_meta_data_DBlockPartition,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DBlockPartition::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBlockPartition::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBlockPartition.stringdata0))
        return static_cast<void*>(this);
    return DBlockDevice::qt_metacast(_clname);
}

int DBlockPartition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBlockDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 12;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DBlockPartition::flagsChanged(qulonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DBlockPartition::isContainedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DBlockPartition::isContainerChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DBlockPartition::nameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DBlockPartition::numberChanged(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DBlockPartition::offsetChanged(qulonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DBlockPartition::sizeChanged(qulonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DBlockPartition::typeChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DBlockPartition::eTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DBlockPartition::UUIDChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DBlockPartition::guidTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
