/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -i udisks2_interface.h -p :udisks2_interface.cpp org.freedesktop.UDisks2.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "udisks2_interface.h"
/*
 * Implementation of interface class OrgFreedesktopUDisks2BlockInterface
 */

OrgFreedesktopUDisks2BlockInterface::OrgFreedesktopUDisks2BlockInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2BlockInterface::~OrgFreedesktopUDisks2BlockInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2DriveInterface
 */

OrgFreedesktopUDisks2DriveInterface::OrgFreedesktopUDisks2DriveInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2DriveInterface::~OrgFreedesktopUDisks2DriveInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2DriveAtaInterface
 */

OrgFreedesktopUDisks2DriveAtaInterface::OrgFreedesktopUDisks2DriveAtaInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2DriveAtaInterface::~OrgFreedesktopUDisks2DriveAtaInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2EncryptedInterface
 */

OrgFreedesktopUDisks2EncryptedInterface::OrgFreedesktopUDisks2EncryptedInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2EncryptedInterface::~OrgFreedesktopUDisks2EncryptedInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2FilesystemInterface
 */

OrgFreedesktopUDisks2FilesystemInterface::OrgFreedesktopUDisks2FilesystemInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2FilesystemInterface::~OrgFreedesktopUDisks2FilesystemInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2JobInterface
 */

OrgFreedesktopUDisks2JobInterface::OrgFreedesktopUDisks2JobInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2JobInterface::~OrgFreedesktopUDisks2JobInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2LoopInterface
 */

OrgFreedesktopUDisks2LoopInterface::OrgFreedesktopUDisks2LoopInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2LoopInterface::~OrgFreedesktopUDisks2LoopInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2MDRaidInterface
 */

OrgFreedesktopUDisks2MDRaidInterface::OrgFreedesktopUDisks2MDRaidInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2MDRaidInterface::~OrgFreedesktopUDisks2MDRaidInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2ManagerInterface
 */

OrgFreedesktopUDisks2ManagerInterface::OrgFreedesktopUDisks2ManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2ManagerInterface::~OrgFreedesktopUDisks2ManagerInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2PartitionInterface
 */

OrgFreedesktopUDisks2PartitionInterface::OrgFreedesktopUDisks2PartitionInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2PartitionInterface::~OrgFreedesktopUDisks2PartitionInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2PartitionTableInterface
 */

OrgFreedesktopUDisks2PartitionTableInterface::OrgFreedesktopUDisks2PartitionTableInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2PartitionTableInterface::~OrgFreedesktopUDisks2PartitionTableInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopUDisks2SwapspaceInterface
 */

OrgFreedesktopUDisks2SwapspaceInterface::OrgFreedesktopUDisks2SwapspaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopUDisks2SwapspaceInterface::~OrgFreedesktopUDisks2SwapspaceInterface()
{
}

